'use strict';

var tiktoken = require('@langchain/core/utils/tiktoken');

async function strTokenCounter(messageContent) {
  if (typeof messageContent === "string") {
    return (await tiktoken.encodingForModel("gpt-4")).encode(messageContent).length;
  }
  if (messageContent.every((x) => x.type === "text" && x.text)) {
    return (await tiktoken.encodingForModel("gpt-4")).encode(
      messageContent.map(({ text }) => text).join("")
    ).length;
  }
  throw new Error(
    `Unsupported message content ${JSON.stringify(messageContent)}`
  );
}
async function tiktokenCounter(messages) {
  let numTokens = 3;
  const tokensPerMessage = 3;
  const tokensPerName = 1;
  const roleBuffer = 20;
  for (const msg of messages) {
    numTokens += tokensPerMessage + roleBuffer + await strTokenCounter(msg.content);
    if (msg.name) {
      numTokens += tokensPerName + await strTokenCounter(msg.name);
    }
  }
  return numTokens;
}

exports.tiktokenCounter = tiktokenCounter;
//# sourceMappingURL=modifier.cjs.js.map
